@@ -508,6 +508,8 @@ eWallet::~eWallet ()
 	//delete ::dbManager;
 }
 
+
+
 /*
  * TYPES
  * 	S -> String
@@ -519,80 +521,211 @@ eWallet::~eWallet ()
  *  H -> Phone number
  */
 void eWallet::loadTypesAndFields () {
-	  QFile file(":/resources/types.txt");
-	  QString line;
-
 	  types = new QList<QString>;
 	  fieldsByType = new QList<QList<TargetField>*>;
 
-	  if ( file.open(QIODevice::Text | QIODevice::ReadOnly) ) {
-	    // file opened successfully
-	    QTextStream t(&file);        // use a text stream
-	    // until end of file...
-	    int i = 0;
-	    while ( !t.atEnd() ) {
-	      // read and parse the command line
-	      QString line = t.readLine();         // line of text excluding '\n'
-	      // do something with the line
+	  this->types->append(QString("Membership Info"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Organization"),TYPE_STRING, true, 2,"Organization"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Phone Number"),TYPE_PHONE_NUMBER, true, 3,"Phone Number"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Other Information"),TYPE_STRING, true, 4,"Other Information"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("User Name"),TYPE_STRING, true, 5,"User Name"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Password"),TYPE_PASSWORD, true, 6,"Password"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Organization club"),TYPE_STRING, true, 7,"Organization club"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("ID Number"),TYPE_INTEGER, true, 8,"ID Number"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("URL"),TYPE_URL, true, 9,"URL"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Card Notes"),TYPE_TEXT, true, 10,"Card Notes"));
+	  this->types->append(QString("Password"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("System"),TYPE_STRING, true, 2,"System"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("User Name"),TYPE_STRING, true, 3,"User Name"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Password"),TYPE_PASSWORD, true, 4,"Password"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("URL"),TYPE_URL, true, 5,"URL"));
+	  this->types->append(QString("Credit Card"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Credit Card Type"),TYPE_STRING, true, 2,"Credit Card Type"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Card Provider"),TYPE_STRING, true, 3,"Card Provider"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Card Number"),TYPE_INTEGER, true, 4,"Card Number"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Expiration Date"),TYPE_DATE, true, 5,"Expiration Date"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Name on Card"),TYPE_STRING, true, 6,"Name on Card"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Phone Number"),TYPE_PHONE_NUMBER, true, 7,"Phone Number"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("PIN"),TYPE_PASSWORD, true, 8,"PIN"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Start Date"),TYPE_DATE, true, 9,"Start Date"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Expiration Date"),TYPE_DATE, true, 10,"Expiration Date"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Detail"),TYPE_STRING, true, 11,"Detail"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("3-digit CVC#"),TYPE_STRING, true, 12,"3-digit CVC#"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Card Notes"),TYPE_TEXT, true, 13,"Card Notes"));
+	  this->types->append(QString("Bank Account"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Bank Name"),TYPE_STRING, true, 2,"Bank Name"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Account Number"),TYPE_INTEGER, true, 3,"Account Number"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Telephone"),TYPE_PHONE_NUMBER, true, 4,"Telephone"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("PIN"),TYPE_PASSWORD, true, 5,"PIN"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("SWIFT Code"),TYPE_STRING, true, 6,"SWIFT Code"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Other Information"),TYPE_STRING, true, 7,"Other Information"));
+	  this->types->append(QString("Health Numbers"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("ID Number"),TYPE_INTEGER, true, 2,"ID Number"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Password"),TYPE_PASSWORD, true, 3,"Password"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Card Title"),TYPE_STRING, true, 4,"Card Title"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Card Notes"),TYPE_TEXT, true, 5,"Card Notes"));
+	  this->types->append(QString("Passport Info"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Passport No"),TYPE_STRING, true, 2,"Passport No"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Surname"),TYPE_STRING, true, 3,"Surname"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Given names"),TYPE_STRING, true, 4,"Given names"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Date of birth"),TYPE_DATE, true, 5,"Date of birth"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Date of issue"),TYPE_DATE, true, 6,"Date of issue"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Date of expiration"),TYPE_DATE, true, 7,"Date of expiration"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Authority"),TYPE_STRING, true, 8,"Authority"));
+	  this->types->append(QString("Note Card"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Text"),TYPE_STRING, true, 2,"Text"));
+	  this->types->append(QString("Car Info"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Model"),TYPE_STRING, true, 2,"Model"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Vehicle Number"),TYPE_INTEGER, true, 3,"Vehicle Number"));
+	  this->types->append(QString("Cellular Phone"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Model"),TYPE_STRING, true, 2,"Model"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Brand"),TYPE_STRING, true, 3,"Brand"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("IMEI#"),TYPE_STRING, true, 4,"IMEI#"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Firmware code"),TYPE_STRING, true, 5,"Firmware code"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Purchased"),TYPE_DATE, true, 6,"Purchased"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Pin1"),TYPE_STRING, true, 7,"Pin1"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Pin2"),TYPE_STRING, true, 8,"Pin2"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Puk1"),TYPE_STRING, true, 9,"Puk1"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Puk2"),TYPE_STRING, true, 10,"Puk2"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Num SIM"),TYPE_STRING, true, 11,"Num SIM"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Password"),TYPE_PASSWORD, true, 12,"Password"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Phone Number"),TYPE_PHONE_NUMBER, true, 13,"Phone Number"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Manufacturer"),TYPE_STRING, true, 14,"Manufacturer"));
+	  this->types->append(QString("Serial Number Software"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Product"),TYPE_STRING, true, 2,"Product"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Version"),TYPE_STRING, true, 3,"Version"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Serial #"),TYPE_STRING, true, 4,"Serial #"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("URL"),TYPE_URL, true, 5,"URL"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Company"),TYPE_STRING, true, 6,"Company"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Date bought"),TYPE_DATE, true, 7,"Date bought"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Username"),TYPE_STRING, true, 8,"Username"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Login"),TYPE_STRING, true, 9,"Login"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Authorization key"),TYPE_STRING, true, 10,"Authorization key"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Price paid"),TYPE_STRING, true, 11,"Price paid"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Support"),TYPE_STRING, true, 12,"Support"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Notes"),TYPE_TEXT, true, 13,"Notes"));
+	  this->types->append(QString("Serial Number Hardware"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Product"),TYPE_STRING, true, 2,"Product"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Serial #"),TYPE_STRING, true, 3,"Serial #"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Model #"),TYPE_STRING, true, 4,"Model #"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Bought from"),TYPE_STRING, true, 5,"Bought from"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Price paid"),TYPE_STRING, true, 6,"Price paid"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Guarantee period"),TYPE_DATE, true, 7,"Guarantee period"));
+	  this->types->append(QString("Web site"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("URL"),TYPE_URL, true, 2,"URL"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Login"),TYPE_STRING, true, 3,"Login"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Password"),TYPE_PASSWORD, true, 4,"Password"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("E mail used"),TYPE_STRING, true, 5,"E mail used"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Notes"),TYPE_TEXT, true, 6,"Notes"));
+	  this->types->append(QString("ID Card"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("ID Number"),TYPE_INTEGER, true, 2,"ID Number"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Card Title"),TYPE_STRING, true, 3,"Card Title"));
+	  this->types->append(QString("Social Security Number"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Social Security Number"),TYPE_INTEGER, true, 2,"Social Security Number"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Name"),TYPE_STRING, true, 3,"Name"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Password"),TYPE_PASSWORD, true, 4,"Password"));
+	  this->types->append(QString("Email Account"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("User Name"),TYPE_STRING, true, 2,"User Name"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Password"),TYPE_PASSWORD, true, 3,"Password"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("System"),TYPE_STRING, true, 4,"System"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Card Notes"),TYPE_TEXT, true, 5,"Card Notes"));
+	  this->types->append(QString("Driver's License"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Driver's License Number"),TYPE_INTEGER, true, 2,"Driver's License Number"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Date Issued"),TYPE_DATE, true, 3,"Date Issued"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Expiration Date"),TYPE_DATE, true, 4,"Expiration Date"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("URL"),TYPE_URL, true, 5,"URL"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Password"),TYPE_PASSWORD, true, 6,"Password"));
+	  this->types->append(QString("Others"));
+	  this->fieldsByType->append (new QList<TargetField>);
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Card Notes"),TYPE_TEXT, true, 2,"Card Notes"));
 
-	      if (line.length() > 0) {
-	    	  if ((i++) == 0) {
-	    		  int p = line.indexOf(';');
-	    		  if (p >= 0) {
-	    			  // TODO
-	    			  QChar imageType = line.at(p + 1);
-					  this->types->append(line.mid(0, p).trimmed());
-	    		  }
-	    		  else {
-					  this->types->append(line);
-	    		  }
-	    		  this->fieldsByType->append (new QList<TargetField>);
-				  ////qDebug () << " new type "<< line << " " << this->types.length();
-	    	  }
-	    	  else {
-	    		  int p = line.indexOf(';');
-	    		  if (p >= 0) {
-	    			  int type = TYPE_STRING;
-	    			  switch (line.at(p + 1).toAscii()) {
-						  case 'T':
-							  type = TYPE_TEXT;
-							  break;
-						  case 'D':
-							  type = TYPE_DATE;
-							  break;
-						  case 'U':
-							  type = TYPE_URL;
-							  break;
-						  case 'P':
-							  type = TYPE_PASSWORD;
-							  break;
-						  case 'N':
-							  type = TYPE_INTEGER;
-							  break;
-						  case 'H':
-							  type = TYPE_PHONE_NUMBER;
-							  break;
-						  case 'S':
-						  default:
-			    			  type = TYPE_STRING;
-						}
-	    			  this->fieldsByType->at(this->types->length() - 1)->append(TargetField (line.mid(0, p).trimmed(), type, true, i));
-	    		  }
-	    		  else {
-	    			  this->fieldsByType->at(this->types->length() - 1)->append(TargetField (line, TYPE_STRING, true, i));
-	    		  }
-				  ////qDebug () << " new field "<< line << " " << this->types.length();
-	    	  }
-	      }
-	      else {
-	    	  i = 0;
-	      }
-
-	    }
-
-	    // Close the file
-	    file.close();
-	  }
+//	  QFile file(":/resources/types.txt");
+//	  QString line;
+//
+//	  if ( file.open(QIODevice::Text | QIODevice::ReadOnly) ) {
+//	    // file opened successfully
+//	    QTextStream t(&file);        // use a text stream
+//	    // until end of file...
+//	    int i = 0;
+//	    while ( !t.atEnd() ) {
+//	      // read and parse the command line
+//	      QString line = t.readLine();         // line of text excluding '\n'
+//	      // do something with the line
+//
+//	      if (line.length() > 0) {
+//	    	  if ((i++) == 0) {
+//	    		  int p = line.indexOf(';');
+//	    		  if (p >= 0) {
+//	    			  // TODO
+//	    			  QChar imageType = line.at(p + 1);
+//					  this->types->append(line.mid(0, p).trimmed());
+//	    		  }
+//	    		  else {
+//					  this->types->append(line);
+//	    		  }
+//	    		  this->fieldsByType->append (new QList<TargetField>);
+//				  ////qDebug () << " new type "<< line << " " << this->types.length();
+//	    	  }
+//	    	  else {
+//	    		  int p = line.indexOf(';');
+//	    		  if (p >= 0) {
+//	    			  int type = TYPE_STRING;
+//	    			  switch (line.at(p + 1).toAscii()) {
+//						  case 'T':
+//							  type = TYPE_TEXT;
+//							  break;
+//						  case 'D':
+//							  type = TYPE_DATE;
+//							  break;
+//						  case 'U':
+//							  type = TYPE_URL;
+//							  break;
+//						  case 'P':
+//							  type = TYPE_PASSWORD;
+//							  break;
+//						  case 'N':
+//							  type = TYPE_INTEGER;
+//							  break;
+//						  case 'H':
+//							  type = TYPE_PHONE_NUMBER;
+//							  break;
+//						  case 'S':
+//						  default:
+//			    			  type = TYPE_STRING;
+//						}
+//	    			  this->fieldsByType->at(this->types->length() - 1)->append(TargetField (line.mid(0, p).trimmed(), type, true, i));
+//	    		  }
+//	    		  else {
+//	    			  this->fieldsByType->at(this->types->length() - 1)->append(TargetField (line, TYPE_STRING, true, i));
+//	    		  }
+//				  ////qDebug () << " new field "<< line << " " << this->types.length();
+//	    	  }
+//	      }
+//	      else {
+//	    	  i = 0;
+//	      }
+//
+//	    }
+//
+//	    // Close the file
+//	    file.close();
+//	  }
 }
 
 void eWallet::keyPressEvent(QKeyEvent* event) {
