@@ -201,7 +201,7 @@
     <message>
         <location filename="../../DetailedWindow.cpp" line="195"/>
         <source>Serial Number Hardware</source>
-        <translation>Serial Number Hardware</translation>
+        <translation>Número de serie Hardware</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="196"/>
@@ -285,7 +285,7 @@
         <location filename="../../DetailedWindow.cpp" line="775"/>
         <location filename="../../DetailedWindow.cpp" line="913"/>
         <source>Images (*.png);;</source>
-        <translation>Imagenes (*.png);;</translation>
+        <translation>Imagenes (*.png);</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="787"/>
@@ -296,7 +296,7 @@
         <location filename="../../DetailedWindow.cpp" line="789"/>
         <location filename="../../DetailedWindow.cpp" line="928"/>
         <source>Images (*.png *.jpg *.gif *.jpeg);;</source>
-        <translation>Imagenes (*.png *.jpg *.gif *.jpeg);;</translation>
+        <translation>Imagenes (*.png *.jpg *.gif *.jpeg);</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="911"/>
@@ -389,127 +389,475 @@
     </message>
     <message>
         <location filename="../../eWallet.cpp" line="366"/>
-        <location filename="../../eWallet.cpp" line="685"/>
+        <location filename="../../eWallet.cpp" line="819"/>
         <source>&lt;All&gt;</source>
         <translation>&lt;Todos&gt;</translation>
     </message>
     <message>
         <location filename="../../eWallet.cpp" line="385"/>
-        <location filename="../../eWallet.cpp" line="694"/>
+        <location filename="../../eWallet.cpp" line="828"/>
         <source>&lt;No Group&gt;</source>
         <translation>&lt;Sin Grupo&gt;</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="774"/>
+        <location filename="../../eWallet.cpp" line="529"/>
+        <source>Organization</source>
+        <translation>Organización</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="530"/>
+        <location filename="../../eWallet.cpp" line="551"/>
+        <location filename="../../eWallet.cpp" line="601"/>
+        <source>Phone Number</source>
+        <translation>Número móvil</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="531"/>
+        <location filename="../../eWallet.cpp" line="565"/>
+        <source>Other Information</source>
+        <translation>Otra información</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="532"/>
+        <location filename="../../eWallet.cpp" line="541"/>
+        <location filename="../../eWallet.cpp" line="643"/>
+        <source>User Name</source>
+        <translation>Usuario</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="533"/>
+        <location filename="../../eWallet.cpp" line="542"/>
+        <location filename="../../eWallet.cpp" line="569"/>
+        <location filename="../../eWallet.cpp" line="600"/>
+        <location filename="../../eWallet.cpp" line="629"/>
+        <location filename="../../eWallet.cpp" line="640"/>
+        <location filename="../../eWallet.cpp" line="644"/>
+        <location filename="../../eWallet.cpp" line="653"/>
+        <source>Password</source>
+        <translation>Password</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="534"/>
+        <source>Organization club</source>
+        <translation>Club</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="535"/>
+        <location filename="../../eWallet.cpp" line="568"/>
+        <location filename="../../eWallet.cpp" line="634"/>
+        <source>ID Number</source>
+        <translation>Número</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="536"/>
+        <location filename="../../eWallet.cpp" line="543"/>
+        <location filename="../../eWallet.cpp" line="608"/>
+        <location filename="../../eWallet.cpp" line="627"/>
+        <location filename="../../eWallet.cpp" line="652"/>
+        <source>URL</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="537"/>
+        <location filename="../../eWallet.cpp" line="557"/>
+        <location filename="../../eWallet.cpp" line="571"/>
+        <location filename="../../eWallet.cpp" line="646"/>
+        <location filename="../../eWallet.cpp" line="656"/>
+        <source>Card Notes</source>
+        <translation>Notas</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="540"/>
+        <location filename="../../eWallet.cpp" line="645"/>
+        <source>System</source>
+        <translation>Sistema</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="546"/>
+        <source>Credit Card Type</source>
+        <translation>Tipo</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="547"/>
+        <source>Card Provider</source>
+        <translation>Proveedor</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="548"/>
+        <source>Card Number</source>
+        <translation>Número</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="549"/>
+        <location filename="../../eWallet.cpp" line="554"/>
+        <location filename="../../eWallet.cpp" line="651"/>
+        <source>Expiration Date</source>
+        <translation>Fecha expiración</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="550"/>
+        <source>Name on Card</source>
+        <translation>Nombre en la tarjeta</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="552"/>
+        <location filename="../../eWallet.cpp" line="563"/>
+        <source>PIN</source>
+        <translation>PIN</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="553"/>
+        <source>Start Date</source>
+        <translation>Fecha inicio</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="555"/>
+        <source>Detail</source>
+        <translation>Detalle</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="556"/>
+        <source>3-digit CVC#</source>
+        <translation>CVC</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="560"/>
+        <source>Bank Name</source>
+        <translation>Nombre banco</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="561"/>
+        <source>Account Number</source>
+        <translation>Número de cuenta</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="562"/>
+        <source>Telephone</source>
+        <translation>Teléfono</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="564"/>
+        <source>SWIFT Code</source>
+        <translation>código SWIFT</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="570"/>
+        <location filename="../../eWallet.cpp" line="635"/>
+        <source>Card Title</source>
+        <translation>Título</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="574"/>
+        <source>Passport No</source>
+        <translation>Número pasaporte</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="575"/>
+        <source>Surname</source>
+        <translation>Nombre</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="576"/>
+        <source>Given names</source>
+        <translation>Apellidos</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="577"/>
+        <source>Date of birth</source>
+        <translation>Fecha nacimiento</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="578"/>
+        <source>Date of issue</source>
+        <translation>Fecha emisión</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="579"/>
+        <source>Date of expiration</source>
+        <translation>Fecha caducidad</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="580"/>
+        <source>Authority</source>
+        <translation>Autoridad</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="583"/>
+        <source>Text</source>
+        <translation>Texto</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="586"/>
+        <location filename="../../eWallet.cpp" line="590"/>
+        <source>Model</source>
+        <translation>Modelo</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="587"/>
+        <source>Vehicle Number</source>
+        <translation>Número</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="591"/>
+        <source>Brand</source>
+        <translation>Marca</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="592"/>
+        <source>IMEI#</source>
+        <translation>IMEI</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="593"/>
+        <source>Firmware code</source>
+        <translation>Firmware code</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="594"/>
+        <source>Purchased</source>
+        <translation>Comprado en</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="595"/>
+        <source>Pin1</source>
+        <translation>Pin 1</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="596"/>
+        <source>Pin2</source>
+        <translation>Pin 2</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="597"/>
+        <source>Puk1</source>
+        <translation>Puk 1</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="598"/>
+        <source>Puk2</source>
+        <translation>Puk 2</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="599"/>
+        <source>Num SIM</source>
+        <translation>Número SIM</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="602"/>
+        <source>Manufacturer</source>
+        <translation>Fabricante</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="605"/>
+        <location filename="../../eWallet.cpp" line="619"/>
+        <source>Product</source>
+        <translation>Producto</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="606"/>
+        <source>Version</source>
+        <translation>Versión</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="607"/>
+        <location filename="../../eWallet.cpp" line="620"/>
+        <source>Serial #</source>
+        <translation>Número de serie</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="609"/>
+        <source>Company</source>
+        <translation>Compañía</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="610"/>
+        <source>Date bought</source>
+        <translation>Fecha de compra</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="611"/>
+        <source>Username</source>
+        <translation>Usuario</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="612"/>
+        <location filename="../../eWallet.cpp" line="628"/>
+        <source>Login</source>
+        <translation>Login</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="613"/>
+        <source>Authorization key</source>
+        <translation>Clave autorización</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="614"/>
+        <location filename="../../eWallet.cpp" line="623"/>
+        <source>Price paid</source>
+        <translation>Precio compra</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="615"/>
+        <source>Support</source>
+        <translation>Soporte</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="616"/>
+        <location filename="../../eWallet.cpp" line="631"/>
+        <source>Notes</source>
+        <translation>Notas</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="621"/>
+        <source>Model #</source>
+        <translation>Modelo</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="622"/>
+        <source>Bought from</source>
+        <translation>Comprado en</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="624"/>
+        <source>Guarantee period</source>
+        <translation>Periodo de garantía</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="630"/>
+        <source>E mail used</source>
+        <translation>Email</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="638"/>
+        <source>Social Security Number</source>
+        <translation>Número Seguridad social</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="639"/>
+        <source>Name</source>
+        <translation>Nombre</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="649"/>
+        <source>Driver&apos;s License Number</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="650"/>
+        <source>Date Issued</source>
+        <translation>Fecha emisión</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="908"/>
         <source>About</source>
         <translation>Acerca de</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="776"/>
+        <location filename="../../eWallet.cpp" line="910"/>
         <source>Delete DB</source>
         <translation>Borrar DB</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="778"/>
-        <location filename="../../eWallet.cpp" line="789"/>
+        <location filename="../../eWallet.cpp" line="912"/>
+        <location filename="../../eWallet.cpp" line="923"/>
         <source>Exit</source>
         <translation>Salir</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="781"/>
+        <location filename="../../eWallet.cpp" line="915"/>
         <source>New</source>
         <translation>Nueva</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="783"/>
-        <location filename="../../eWallet.cpp" line="1257"/>
+        <location filename="../../eWallet.cpp" line="917"/>
+        <location filename="../../eWallet.cpp" line="1391"/>
         <source>Edit</source>
         <translation>Modificar</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="784"/>
+        <location filename="../../eWallet.cpp" line="918"/>
         <source>Invert Sort</source>
         <translation>Invertir el orden</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="785"/>
+        <location filename="../../eWallet.cpp" line="919"/>
         <source>Import</source>
         <translation>Importar</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="786"/>
+        <location filename="../../eWallet.cpp" line="920"/>
         <source>Export</source>
         <translation>Exportar</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="788"/>
+        <location filename="../../eWallet.cpp" line="922"/>
         <source>Change Password</source>
         <translation>Cambiar Password</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="848"/>
+        <location filename="../../eWallet.cpp" line="982"/>
         <source>Are you sure you want to remove it?</source>
         <translation>¿Está seguro que quiere borrar la tarjeta?</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="996"/>
+        <location filename="../../eWallet.cpp" line="1130"/>
         <source>Choose import file</source>
         <translation>Elije un fichero a importar</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="998"/>
-        <location filename="../../eWallet.cpp" line="1273"/>
+        <location filename="../../eWallet.cpp" line="1132"/>
+        <location filename="../../eWallet.cpp" line="1407"/>
         <source>Text files (*.txt);;</source>
-        <translation>Archivos de texto (*.txt);;</translation>
+        <translation>Archivos de texto (*.txt);</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1246"/>
+        <location filename="../../eWallet.cpp" line="1380"/>
         <source>Rename</source>
         <translation>Renombrar</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1247"/>
-        <location filename="../../eWallet.cpp" line="1260"/>
+        <location filename="../../eWallet.cpp" line="1381"/>
+        <location filename="../../eWallet.cpp" line="1394"/>
         <source>Delete</source>
         <translation>Borrar</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1256"/>
+        <location filename="../../eWallet.cpp" line="1390"/>
         <source>View</source>
         <translation>Ver</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1258"/>
+        <location filename="../../eWallet.cpp" line="1392"/>
         <source>New like this</source>
         <translation>Nueva como esta</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1259"/>
+        <location filename="../../eWallet.cpp" line="1393"/>
         <source>Duplicate</source>
         <translation>Duplicar</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1271"/>
+        <location filename="../../eWallet.cpp" line="1405"/>
         <source>Choose export file</source>
         <translation>Elije el fichero de exportación</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1476"/>
+        <location filename="../../eWallet.cpp" line="1610"/>
         <source>About Wallet</source>
         <translation>Acerca de Wallet</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1511"/>
+        <location filename="../../eWallet.cpp" line="1645"/>
         <source>Changing password, please wait until application quits</source>
         <translation>Cambiando el password, espere hasta que la aplicación finalice</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1517"/>
+        <location filename="../../eWallet.cpp" line="1651"/>
         <source>Password changed successfully, application will exit</source>
         <translation>Password cambiado. La aplicación finalizará sola</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1519"/>
+        <location filename="../../eWallet.cpp" line="1653"/>
         <source>Password CANNOT BE changed, because %1, and application will exit</source>
         <translation>No se puede cambiar el password por %1, y la applicación finalizará sola</translation>
     </message>
