@@ -36,7 +36,7 @@
     <message>
         <location filename="../../DetailedWindow.cpp" line="1076"/>
         <source>Phone Number</source>
-        <translation>Numéro de téléphone</translation>
+        <translation>Téléphone</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="1077"/>
@@ -181,7 +181,7 @@
     <message>
         <location filename="../../DetailedWindow.cpp" line="191"/>
         <source>Note Card</source>
-        <translation>Commentaire carte</translation>
+        <translation>Notes diverses</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="192"/>
@@ -196,12 +196,12 @@
     <message>
         <location filename="../../DetailedWindow.cpp" line="194"/>
         <source>Serial Number Software</source>
-        <translation>Numéro de série du logiciel</translation>
+        <translation>Descriptif logiciel</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="195"/>
         <source>Serial Number Hardware</source>
-        <translation>Numéro de série du matériel</translation>
+        <translation>Descriptif matériel</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="196"/>
@@ -285,7 +285,7 @@
         <location filename="../../DetailedWindow.cpp" line="775"/>
         <location filename="../../DetailedWindow.cpp" line="913"/>
         <source>Images (*.png);;</source>
-        <translation>Images (*.png);;</translation>
+        <translation>Images (*.png);</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="787"/>
@@ -296,7 +296,7 @@
         <location filename="../../DetailedWindow.cpp" line="789"/>
         <location filename="../../DetailedWindow.cpp" line="928"/>
         <source>Images (*.png *.jpg *.gif *.jpeg);;</source>
-        <translation>Images (*.png *.jpg *.gif *.jpeg);;</translation>
+        <translation>Images (*.png *.jpg *.gif *.jpeg);</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="911"/>
@@ -379,13 +379,13 @@
     <name>eWallet</name>
     <message>
         <location filename="../../eWallet.cpp" line="366"/>
-        <location filename="../../eWallet.cpp" line="685"/>
+        <location filename="../../eWallet.cpp" line="819"/>
         <source>&lt;All&gt;</source>
         <translation>&lt;Tout&gt;</translation>
     </message>
     <message>
         <location filename="../../eWallet.cpp" line="385"/>
-        <location filename="../../eWallet.cpp" line="694"/>
+        <location filename="../../eWallet.cpp" line="828"/>
         <source>&lt;No Group&gt;</source>
         <translation>&lt;Pas de groupe&gt;</translation>
     </message>
@@ -400,116 +400,464 @@
         <translation>Mot de passe erroné</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="774"/>
+        <location filename="../../eWallet.cpp" line="529"/>
+        <source>Organization</source>
+        <translation>Organisation</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="530"/>
+        <location filename="../../eWallet.cpp" line="551"/>
+        <location filename="../../eWallet.cpp" line="601"/>
+        <source>Phone Number</source>
+        <translation>Téléphone</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="531"/>
+        <location filename="../../eWallet.cpp" line="565"/>
+        <source>Other Information</source>
+        <translation>Autre information</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="532"/>
+        <location filename="../../eWallet.cpp" line="541"/>
+        <location filename="../../eWallet.cpp" line="643"/>
+        <source>User Name</source>
+        <translation>Nom utilisateur</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="533"/>
+        <location filename="../../eWallet.cpp" line="542"/>
+        <location filename="../../eWallet.cpp" line="569"/>
+        <location filename="../../eWallet.cpp" line="600"/>
+        <location filename="../../eWallet.cpp" line="629"/>
+        <location filename="../../eWallet.cpp" line="640"/>
+        <location filename="../../eWallet.cpp" line="644"/>
+        <location filename="../../eWallet.cpp" line="653"/>
+        <source>Password</source>
+        <translation>Mot de passe</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="534"/>
+        <source>Organization club</source>
+        <translation>Club</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="535"/>
+        <location filename="../../eWallet.cpp" line="568"/>
+        <location filename="../../eWallet.cpp" line="634"/>
+        <source>ID Number</source>
+        <translation>Identifiant</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="536"/>
+        <location filename="../../eWallet.cpp" line="543"/>
+        <location filename="../../eWallet.cpp" line="608"/>
+        <location filename="../../eWallet.cpp" line="627"/>
+        <location filename="../../eWallet.cpp" line="652"/>
+        <source>URL</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="537"/>
+        <location filename="../../eWallet.cpp" line="557"/>
+        <location filename="../../eWallet.cpp" line="571"/>
+        <location filename="../../eWallet.cpp" line="646"/>
+        <location filename="../../eWallet.cpp" line="656"/>
+        <source>Card Notes</source>
+        <translation>Notes</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="540"/>
+        <location filename="../../eWallet.cpp" line="645"/>
+        <source>System</source>
+        <translation>Système</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="546"/>
+        <source>Credit Card Type</source>
+        <translation>Type</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="547"/>
+        <source>Card Provider</source>
+        <translation>Organisme</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="548"/>
+        <source>Card Number</source>
+        <translation>Numéro</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="549"/>
+        <location filename="../../eWallet.cpp" line="554"/>
+        <location filename="../../eWallet.cpp" line="651"/>
+        <source>Expiration Date</source>
+        <translation>Expire le</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="550"/>
+        <source>Name on Card</source>
+        <translation>Nom du porteur</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="552"/>
+        <location filename="../../eWallet.cpp" line="563"/>
+        <source>PIN</source>
+        <translation>Code personnel</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="553"/>
+        <source>Start Date</source>
+        <translation>Mise en service le</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="555"/>
+        <source>Detail</source>
+        <translation>Détail</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="556"/>
+        <source>3-digit CVC#</source>
+        <translation>Cryptogramme</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="560"/>
+        <source>Bank Name</source>
+        <translation>Nom de la banque</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="561"/>
+        <source>Account Number</source>
+        <translation>Numéro de compte</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="562"/>
+        <source>Telephone</source>
+        <translation>Téléphone</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="564"/>
+        <source>SWIFT Code</source>
+        <translation>Code SWIFT</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="570"/>
+        <location filename="../../eWallet.cpp" line="635"/>
+        <source>Card Title</source>
+        <translation>Titre</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="574"/>
+        <source>Passport No</source>
+        <translation>Numéro</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="575"/>
+        <source>Surname</source>
+        <translation>Nom de famille</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="576"/>
+        <source>Given names</source>
+        <translation>Prénoms</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="577"/>
+        <source>Date of birth</source>
+        <translation>Date de naissance</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="578"/>
+        <source>Date of issue</source>
+        <translation>Délivré le</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="579"/>
+        <source>Date of expiration</source>
+        <translation>Expire le</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="580"/>
+        <source>Authority</source>
+        <translation>Délivré par</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="583"/>
+        <source>Text</source>
+        <translation>Texte</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="586"/>
+        <location filename="../../eWallet.cpp" line="590"/>
+        <source>Model</source>
+        <translation>Modèle</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="587"/>
+        <source>Vehicle Number</source>
+        <translation>Immatriculation</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="591"/>
+        <source>Brand</source>
+        <translation>Marque</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="592"/>
+        <source>IMEI#</source>
+        <translation>IMEI#</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="593"/>
+        <source>Firmware code</source>
+        <translation>Code du firmware </translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="594"/>
+        <source>Purchased</source>
+        <translation>Acheté le</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="595"/>
+        <source>Pin1</source>
+        <translation>Code personnel 1</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="596"/>
+        <source>Pin2</source>
+        <translation>Code personnel 2</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="597"/>
+        <source>Puk1</source>
+        <translation>Clé de déblocage 1</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="598"/>
+        <source>Puk2</source>
+        <translation>Clé de déblocage 2</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="599"/>
+        <source>Num SIM</source>
+        <translation>Numéro carte SIM</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="602"/>
+        <source>Manufacturer</source>
+        <translation>Fabricant</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="605"/>
+        <location filename="../../eWallet.cpp" line="619"/>
+        <source>Product</source>
+        <translation>Produit</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="606"/>
+        <source>Version</source>
+        <translation>Version</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="607"/>
+        <location filename="../../eWallet.cpp" line="620"/>
+        <source>Serial #</source>
+        <translation>Numéro de série</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="609"/>
+        <source>Company</source>
+        <translation>Compagnie</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="610"/>
+        <source>Date bought</source>
+        <translation>Acheté le</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="611"/>
+        <source>Username</source>
+        <translation>Nom utilisateur</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="612"/>
+        <location filename="../../eWallet.cpp" line="628"/>
+        <source>Login</source>
+        <translation>Identifiant</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="613"/>
+        <source>Authorization key</source>
+        <translation>Clé d'autorisation</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="614"/>
+        <location filename="../../eWallet.cpp" line="623"/>
+        <source>Price paid</source>
+        <translation>Tarif</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="615"/>
+        <source>Support</source>
+        <translation>Support</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="616"/>
+        <location filename="../../eWallet.cpp" line="631"/>
+        <source>Notes</source>
+        <translation>Notes</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="621"/>
+        <source>Model #</source>
+        <translation>Modèle</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="622"/>
+        <source>Bought from</source>
+        <translation>Acheté le</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="624"/>
+        <source>Guarantee period</source>
+        <translation>Fin de garantie</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="630"/>
+        <source>E mail used</source>
+        <translation>Email utilisé</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="638"/>
+        <source>Social Security Number</source>
+        <translation>Numéro de sécurité sociale</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="639"/>
+        <source>Name</source>
+        <translation>Nom</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="649"/>
+        <source>Driver&apos;s License Number</source>
+        <translation>Numéro</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="650"/>
+        <source>Date Issued</source>
+        <translation>Délivré le</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="908"/>
         <source>About</source>
         <translation>A propos de</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="776"/>
+        <location filename="../../eWallet.cpp" line="910"/>
         <source>Delete DB</source>
         <translation>Supprimer BDD</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="778"/>
-        <location filename="../../eWallet.cpp" line="789"/>
+        <location filename="../../eWallet.cpp" line="912"/>
+        <location filename="../../eWallet.cpp" line="923"/>
         <source>Exit</source>
         <translation>Quitter</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="781"/>
+        <location filename="../../eWallet.cpp" line="915"/>
         <source>New</source>
         <translation>Nouveau</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="783"/>
-        <location filename="../../eWallet.cpp" line="1257"/>
+        <location filename="../../eWallet.cpp" line="917"/>
+        <location filename="../../eWallet.cpp" line="1391"/>
         <source>Edit</source>
         <translation>Editer</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="784"/>
+        <location filename="../../eWallet.cpp" line="918"/>
         <source>Invert Sort</source>
         <translation>Tri inversé</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="785"/>
+        <location filename="../../eWallet.cpp" line="919"/>
         <source>Import</source>
         <translation>Importer</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="786"/>
+        <location filename="../../eWallet.cpp" line="920"/>
         <source>Export</source>
         <translation>Exporter</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="788"/>
+        <location filename="../../eWallet.cpp" line="922"/>
         <source>Change Password</source>
         <translation>Changer le mot de passe</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="848"/>
+        <location filename="../../eWallet.cpp" line="982"/>
         <source>Are you sure you want to remove it?</source>
         <translation>Etes-vous sûr de vouloir le supprimer ?</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="996"/>
+        <location filename="../../eWallet.cpp" line="1130"/>
         <source>Choose import file</source>
         <translation>Choisir le fichier d&apos;import</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="998"/>
-        <location filename="../../eWallet.cpp" line="1273"/>
+        <location filename="../../eWallet.cpp" line="1132"/>
+        <location filename="../../eWallet.cpp" line="1407"/>
         <source>Text files (*.txt);;</source>
-        <translation>Fichiers texte (*.txt);;</translation>
+        <translation>Fichiers texte (*.txt);</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1246"/>
+        <location filename="../../eWallet.cpp" line="1380"/>
         <source>Rename</source>
         <translation>Renommer</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1247"/>
-        <location filename="../../eWallet.cpp" line="1260"/>
+        <location filename="../../eWallet.cpp" line="1381"/>
+        <location filename="../../eWallet.cpp" line="1394"/>
         <source>Delete</source>
         <translation>Effacer</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1256"/>
+        <location filename="../../eWallet.cpp" line="1390"/>
         <source>View</source>
         <translation>Voir</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1258"/>
+        <location filename="../../eWallet.cpp" line="1392"/>
         <source>New like this</source>
         <translation>Nouveau comme celui-ci</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1259"/>
+        <location filename="../../eWallet.cpp" line="1393"/>
         <source>Duplicate</source>
         <translation>Dupliquer</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1271"/>
+        <location filename="../../eWallet.cpp" line="1405"/>
         <source>Choose export file</source>
         <translation>Choisir fichier d&apos;export</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1476"/>
+        <location filename="../../eWallet.cpp" line="1610"/>
         <source>About Wallet</source>
         <translation>A propos de Wallet</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1511"/>
+        <location filename="../../eWallet.cpp" line="1645"/>
         <source>Changing password, please wait until application quits</source>
         <translation>Changement du mot de passe en cours, patientez SVP que l&apos;application se ferme</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1517"/>
+        <location filename="../../eWallet.cpp" line="1651"/>
         <source>Password changed successfully, application will exit</source>
         <translation>Mot de passe modifié avec succès, l&apos;application va se fermer</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1519"/>
+        <location filename="../../eWallet.cpp" line="1653"/>
         <source>Password CANNOT BE changed, because %1, and application will exit</source>
         <translation>Le mot de passe ne peut être modifié, parce que %1 et l&apos;application va se fermer</translation>
     </message>
